# bin2tap-metsuos

Ajuste del bin2tap de Raül Torralba para evitar conflictos con skooltools e integrar con metsuos

A command to convert binary file into ZX Spectrum TAP file.

Is a translation from the [JuananZX command](https://github.com/juananZX/scr2tap) from C# to python. Of course thank you so much for share it.

## Installation

```bash
pip install bin2tap-metsuos
```